import { getSlatePluginOptions } from '@udecode/slate-plugins-core';
import { Text } from 'slate';
import { useState } from 'react';
import { useRenderLeaf } from '@udecode/slate-plugins-common';

const MARK_SEARCH_HIGHLIGHT = 'search_highlight';

const useDecorateSearchHighlight = ({
  search
}) => editor => {
  const options = getSlatePluginOptions(editor, MARK_SEARCH_HIGHLIGHT);
  return ([node, path]) => {
    const ranges = [];

    if (search && Text.isText(node)) {
      const {
        text
      } = node;
      const parts = text.split(search);
      let offset = 0;
      parts.forEach((part, i) => {
        if (i !== 0) {
          ranges.push({
            anchor: {
              path,
              offset: offset - search.length
            },
            focus: {
              path,
              offset
            },
            [options.type]: true
          });
        }

        offset = offset + part.length + search.length;
      });
    }

    return ranges;
  };
};

/**
 * Supports search highlight.
 * TODO: replace
 */

const useFindReplacePlugin = () => {
  const [search, setSearch] = useState('');
  return {
    renderLeaf: useRenderLeaf(MARK_SEARCH_HIGHLIGHT),
    decorate: useDecorateSearchHighlight({
      search
    }),
    setSearch
  };
};

export { MARK_SEARCH_HIGHLIGHT, useDecorateSearchHighlight, useFindReplacePlugin };
//# sourceMappingURL=index.es.js.map
