'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var slatePluginsCore = require('@udecode/slate-plugins-core');
var slate = require('slate');
var react = require('react');
var slatePluginsCommon = require('@udecode/slate-plugins-common');

const MARK_SEARCH_HIGHLIGHT = 'search_highlight';

const useDecorateSearchHighlight = ({
  search
}) => editor => {
  const options = slatePluginsCore.getSlatePluginOptions(editor, MARK_SEARCH_HIGHLIGHT);
  return ([node, path]) => {
    const ranges = [];

    if (search && slate.Text.isText(node)) {
      const {
        text
      } = node;
      const parts = text.split(search);
      let offset = 0;
      parts.forEach((part, i) => {
        if (i !== 0) {
          ranges.push({
            anchor: {
              path,
              offset: offset - search.length
            },
            focus: {
              path,
              offset
            },
            [options.type]: true
          });
        }

        offset = offset + part.length + search.length;
      });
    }

    return ranges;
  };
};

/**
 * Supports search highlight.
 * TODO: replace
 */

const useFindReplacePlugin = () => {
  const [search, setSearch] = react.useState('');
  return {
    renderLeaf: slatePluginsCommon.useRenderLeaf(MARK_SEARCH_HIGHLIGHT),
    decorate: useDecorateSearchHighlight({
      search
    }),
    setSearch
  };
};

exports.MARK_SEARCH_HIGHLIGHT = MARK_SEARCH_HIGHLIGHT;
exports.useDecorateSearchHighlight = useDecorateSearchHighlight;
exports.useFindReplacePlugin = useFindReplacePlugin;
//# sourceMappingURL=index.js.map
